MConfig class

Constructors

MConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

assetImageIcCloseImage ↔ String?
getter/setter pair
assetImageLabelArrow ↔ String?
getter/setter pair
assetImageWhenError ↔ String?
getter/setter pair
assetImageWhenLoading ↔ String?
getter/setter pair
customAssetsImage ↔ Widget Function(Image)?
getter/setter pair
defNoDataImage ↔ Widget?
getter/setter pair
isChildDataLoading ↔ RxBool
getter/setter pair
mCustomConfirmDialogValue ↔ dynamic Function(String message, String content, dynamic onConfirm())?
getter/setter pair
mKeyZeroEvent ↔ Rx<MKeyZeroEvent>
getter/setter pair
noDataText ↔ String
getter/setter pair
onShowDialog ↔ VoidCallback?
getter/setter pair
pageLimit ↔ int
getter/setter pair
refreshText ↔ String
getter/setter pair
showCustomToastValue ↔ dynamic Function(String message)?
getter/setter pair