flutter_compose_ui_modifiers library

Classes

Algo
Button
Generic button, supports FlutterUI Modifiers.
ConfirmDialogWidget
DateChipText
DateChipText class included with algorithms which are need to implement DateChip date parameter is required
DefineMAddButtonModifier
Please do not use it, just use MAddButtonModifier.
DefineMColumnModifier
Please do not use it, just use MColumnModifier.
DefineMContainerModifier
Please do not use it, just use MContainerModifier.
DefineMImageModifier
Please do not use it, just use MImageModifier.
DefineMListViewModifier
Please do not use it, just use MListViewModifier.
DefineMRowModifier
Please do not use it, just use MRowModifier.
DefineMScaffoldModifier
Please do not use it, just use MScaffoldModifier.
DefineMStackModifier
Please do not use it, just use MStackModifier.
DefineMTextFieldModifier
Please do not use it, just use MTextFieldModifier.
DefineMTextModifier
Please do not use it, just use MTextModifier.
DefineMTileModifier
Please do not use it, just use MTileModifier.
GetxControllerWithWorks
LoginAgreeHandleInterface
MAddButton
MAnimatedSwitcher
MAnimateFadeContent
Use example:
MAnimateFadeShow
Use example:
MAnimateLeftToRight
Use example:
MAnimateLeftToRightState
MAnimateScale
You must set key to child.
MAppBar
MAssetsImage
MBanner
MBigPicPage
MBlockBackButton
MButton
MButtonController
MButtonGradientBig
MButtonGrey
MButtonMediumGrey
MButtonMediumGreyBorder
MButtonMediumThemeBorder
MButtonMini1
MButtonMini2
MButtonMiniBorderEmptyBg
MButtonMiniCancel
MButtonMiniCancelGrey
MButtonMiniGradient
MButtonSoMiniGradient
MCenterTip
MChatDateChip
MChatEmojiWidget
MChatFooter
MChatHeader
MChatImageBubble
MChatPanel
MChatTextBubble
MClickText
MColumn
MCommonConfirmButton
MCommonConfirmThemeButton
MConfig
MConsoleOutput
Default implementation of LogOutput.
MContainer
MCustomConfirmGradientDialog
MCustomGradientAlarm
MDialogDarkConfirm
MEasyRefresh
MEasyRefreshNoData
MErrorData
MFontWeight
MFormat
MGeneralLayoutModifierWidget
ignoreList: ignore some modifier in general.
MGeneralModifier
MGetxController
Just extends and use.
MGlobalBinding
MGradientText
MHeaderDelegate
Please use SliverPinnedToBoxAdapter in extended_sliver plugin.
MImage
MImagesUpload
MImagesUploadClickUpload
MImgError
MImgLoading
MKeepAliveModifierState<T extends StatefulWidget>
MKeepAliveState<T extends StatefulWidget>
custom a mixin who implement the AutomaticKeepAliveClientMixin and set the if keep as true, by the way, the build method will be Call super down build.
MKeyZeroEvent
MLanUtil
MListView
MLoadingIcon
MLoginAgreementText
MLoginBase
MMediaLogic
MNoData
ModifierMaterialApp
ModifierState<T extends StatefulWidget>
MOppositeColorMiniButton
MPageState<T>
MPanelItem
MPickerImageUtil
MPickImageLogic
MRefreshIndicator
MRow
MRxIntConverter
Use case:
MRxStringConverter
MScaffold
MScrollWidget
MStack
MTabControllerListener
MTabIndicatorSolid
MText
@todo HighlightNamesText function with MText. example:
MTextController
MTextField
MThemeConfig
MTile
MTipRow
MUtil
MWaterRipplesContainer
MWhiteSelectTile
PanelListItem
TimeStartToEndModel
TipsDialog
WaterRipples

Enums

IgnoreModifierInGeneral
if you want to ignore some modifier in general, you can add it here.
LanguageEnumType
MGravity
MIndicatorResult
The status returned after the task is completed.
MInputStatus

Mixins

AutoOnScrollStop<T extends StatefulWidget>
LoginAgreeHandle
MCheckTabBarChange<T extends StatefulWidget>
MGetxControllerMixin
You must extends GetxControllerWithWorks if use it.
ObxImplementation<T extends StatefulWidget>
WorkManager

Extensions

ExtensionMGravity on MGravity
FlutterComposeUiModifierEvent on Widget
FlutterUIBoxDecoration on BoxDecoration
FlutterUIButtonStyle on ButtonStyle
FlutterUIInkWell on InkWell
FlutterUIModifiersColumn on Column
FlutterUIModifiersContainer on Container
Container(Text(""), Modifier()) Contains the modifier members of the Container class.
FlutterUIModifiersIcon on Icon
FlutterUIModifiersImage on Image
FlutterUIModifiersListView on ListView
FlutterUIModifiersRow on Row
FlutterUIModifiersRowList on List
FlutterUIModifiersText on Text
FlutterUIModifiersTextField on TextField
FlutterUIModifiersWidget on Widget
Contains the modifier members of the Widget class.
FlutterUIModifiersWidgetLayout on Widget
InsDelay on int
LanguageEnumTypeExtension on LanguageEnumType
LanToDisplayName on String?
ListCheckConditions on List
ListMultiply on List<T>
Make a extension to allow list to multiply Contents. He is law, we just use multiply market to Do something in like this
ListToWidget on List<Widget>
LocaleExtentsion on Locale?
MAddButtonGeneralGenerator on DefineMAddButtonModifier
MAddButtonModifierPropertys on DefineMAddButtonModifier
MAddStackGeneralGenerator on DefineMStackModifier
MAppBarModifierPropertys on MAppBar
MColumnGeneralGenerator on DefineMColumnModifier
MColumnModifierPropertys on DefineMColumnModifier
MContainerGeneralGenerator on DefineMContainerModifier
MContainerGeneralOk on DefineMContainerModifier
MCopyUtilExtension on Object
MImageGeneralGenerator on DefineMImageModifier
MImageModifierPropertys on DefineMImageModifier
MListViewGeneralGenerator on DefineMListViewModifier
MListViewModifierPropertys on DefineMListViewModifier
ModifierBoolHandle on bool
ModifierExtension on String
ModifierMapHandle on Map
ModifierObjectEmptyCheck on Object?
ModifierStringCheck on String?
MRowGeneralGenerator on DefineMRowModifier
MRowModifierPropertys on DefineMRowModifier
MScaffoldModifierPropertys on DefineMScaffoldModifier
MStackModifierPropertys on DefineMStackModifier
MTextFieldModifierPropertys on DefineMTextFieldModifier
MTextFiledGenerator on DefineMTextFieldModifier
MTextGeneralGenerator on DefineMTextModifier
MTextModifierPropertys on DefineMTextModifier
MTileGeneralGenerator on DefineMTileModifier
MTileModifierPropertys on DefineMTileModifier
OkExtentionOfGeneal on MGeneralModifier
ScreenExtensionDouble on num
SpaceNum on num
TextSpanRich on List<TextSpan>
WidgetMultiple on Widget

Functions

debugDo(VoidCallback onAction, [bool? condition1, bool? condition2, bool? condition3]) → void
mAgreementsTextSpanList(LoginAgreeHandleInterface? interface, {bool? isWhiteAgreementText, Color? lightAgreementColor}) List<TextSpan>
mApiRetry<T>(Future<T> req(bool last)) Future<T?>
Test code:
mDialogAlarmCustomGradient({required String description, required Future<void> onPressed(), String? title, Future<void> onCancel()?, String? okText, required String tag, bool? bindPage}) → void
mDialogConfirm(String title, String? description, Future<void> onPressed(), {Future<void> onCancel()?, Widget? centerWidget, Widget? desWidget, String? okText, bool showCancel = true, required String tag, VoidCallback? onDismiss, Color? buttonColor, Color? cancelButtonColor, Color? bgColor, bool? clickMaskDismiss}) Future<void>
mDialogCupertinoConfirm<T>({required String title, required VoidCallback onYes}) Future<T?>
mDialogCustomConfirm(String title, String content, dynamic onConfirm()) → dynamic
Other dialog please see mConfirmDialog.
mDialogCustomConfirmGradient(String description, Future<void> onPressed(), {Future<void> onCancel()?, String? okText, required String tag, bool? bindPage}) → void
mDialogDarkConfirm(String content, {String? title, String? okText, String? bgImage, double? width, double? height, double? textTopSpace, double? textBottomSpace, required String tag, required VoidCallback onConfirm}) Future<void>
mDialogSelectDays() Future<int?>
mDialogSelectItemsCupertinoPicker<T>(List<String> options) Future<T?>?
mDismissSmartDialog({required String tag}) Future<void>
mEasyGetPageData<T>({required Future<List<T>?> reqData, required MPageState<T> mPageState, List<T>? handleData(List<T> value)?, EasyRefreshController? easyRefreshController}) Future<IndicatorResult>
如果子组件有包含可滑动组件。 要套一个EasyRefresh来隔绝其他的EasyRefresh,防止EasyRefresh的 child 里面有滑动的内容造成层级错误。
mFormatTimeRange(DateTime startTime, DateTime endTime) String
example:
mGetImageProvider(String data) ImageProvider<Object>
mGetPageData<T>({required Future<List<T>?> reqData, required MPageState<T> mPageState, List<T>? handleData(List<T> value)?}) Future<MIndicatorResult>
mIntStr(String? value) bool
mLogWriterCallback(String text, {bool? isError}) → void
mPictureSampleShowBig(String? url, {Object? heroTag}) Future<void>?
mPictureShowBig(String? url, {Object? heroTag}) Future<void>?
mShowCustomToast(String message, {Duration? duration, ToastPosition? position}) → void
mShowErrorToast(String message) → void
mShowSmartDialog({required WidgetBuilder builder, required String tag, SmartDialogController? controller, Alignment? alignment, bool? bindPage, Color? maskColor, VoidCallback? onDismiss, Duration? animationTime, bool? useAnimation, SmartAnimationType? animationType, bool? clickMaskDismiss, Rect? ignoreArea}) Future<void>
mShowSuccessToast(String message) → void
mShowTipsDialog<T>(BuildContext context, {String? centerText, Widget? centerWidget, String confirmText = 'Confirm', required VoidCallback onTap, VoidCallback? onCancel, VoidCallback? onDismiss, bool singleButtonMode = false, Color? okButtonTextColor}) Future<T?>
mShowToastMessage(String message, {IconData? icon, Color? color, Duration? duration, ToastPosition? position}) → void
mToast(String message, {Duration? duration, ToastPosition? position}) → void
myToast(String message, {Duration? duration, ToastPosition? position}) → void
paddingBottom() double
paddingTop() double
paTop() double
pdBottom() double
scHeight() double
screenHeight() double
screenWidth() double
scWidth() double
selectDateTimePicker() Future<TimeStartToEndModel?>
showCustomToastInFiveSecond(String message, {Duration? duration, ToastPosition? position}) → void

Typedefs

AsyncCallbackWithError<T> = Future<T> Function(void (Object error))
BinaryCallback<T, U> = void Function(T a, U b)
function type with multiple parameters
BoolCallBack = void Function(bool value)
Bool
BoolCallBackFuture<T> = Future<T> Function(bool value)
BoolCallBackReturn<T> = T Function(bool value)
BoolCallbackWithInt = bool Function(int value)
CallBack = dynamic Function(dynamic value)
CallBack
CallChatPanel = void Function(String icon)
FutureCallback<T> = Future<T> Function()
General. Function type of return Future value.
IntCallBack = void Function(int value)
Int.
IntCallBackFuture<T> = Future<T> Function(int value)
IntCallBackReturn<T> = T Function(int value)
ListCallBack<T> = void Function(List<T> value)
List.
ListCallBackFuture<T, R> = Future<R> Function(List<T> value)
ListCallBackReturn<T, R> = R Function(List<T> value)
OnImage = dynamic Function(int index)
ReturnCallback<T> = T Function()
Function type of return value.
ReturnCallbackWithParam<T, P> = T Function(P)
Function type of return value.
StringCallBack = void Function(String value)
String.
StringCallBackFuture<T> = Future<T> Function(String value)
StringCallBackReturn<T> = T Function(String value)
StringFutureCallbackWithInt = Future<String> Function(int value)
SumCallback = int Function(int a, int b)
TabControllerWidgetBuilder = Widget Function(BuildContext context, TabController tabController)