MGeneralModifier class

Implementers
Available extensions

Constructors

MGeneralModifier({Key? valueKey, EdgeInsets? valuePadding, EdgeInsets? valueMargin, VoidCallback? valueOnTap, GestureLongPressCallback? valueOnLongPress, GestureLongPressMoveUpdateCallback? valueOnLongPressMoveUpdate, GestureLongPressUpCallback? valueOnLongPressUp, VoidCallback? valueDragOutToStatusBar, Color? valueBackgroundColor, BorderRadiusGeometry? valueBorderRadius, bool? valueCenterAlign, double? valueWidth, double? valueHeight, BoxShadow? valueShadow, Matrix4? valueTransform, BoxConstraints? valueConstraints, double? valueAspectRatio, int? valueFlex, bool? valueOutSizeFlex, String? valueHelp, double? valueOpacity, double? valueRotate, double? valueScale, Gradient? valueGradient, Border? valueBorder, BoxShape? valueShape, String? valueBackgroundImage, BoxFit? valueBackgroundImageFit, MGravity? valueGravity, Gradient? valueGradientBorder, double? valueGradientBorderSize, double? valueFullWidth, double? valueFullHeight, AlignmentGeometry? valueContainerAlignment, AlignmentGeometry? valueOutSideAlignment, bool? valueCancelFocusWhenClick, Color? valueOutsideBackgroundColor, BorderRadiusGeometry? valueOutsideBorderRadius, Border? valueOutsideBorder, double? valueLeft, double? valueRight, double? valueTop, double? valueBottom, bool? valueScrollable, ScrollController? valueScrollController, VoidCallback? valueOnScrollStop, double? valueSigmaX, double? valueSigmaY, Color? valueMaskColor, MaterialType? valueMaterialType, double? valueMaterialElevation, SafeArea? valueSafeArea, bool? valueVisible, int? valueTabLength, Object? valueHeroTag, RxInterface? valueObxListener})
const

Properties

getFullPaddingHorizontal → double

Available on MGeneralModifier, provided by the OkExtentionOfGeneal extension

no setter
getFullPaddingVertical → double

Available on MGeneralModifier, provided by the OkExtentionOfGeneal extension

no setter
getFullSize → Size

Available on MGeneralModifier, provided by the OkExtentionOfGeneal extension

no setter
getFullSizeHeight → double

Available on MGeneralModifier, provided by the OkExtentionOfGeneal extension

no setter
getFullSizeWidth → double

Available on MGeneralModifier, provided by the OkExtentionOfGeneal extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueAspectRatio → double?
final
valueBackgroundColor → Color?
final
valueBackgroundImage → String?
final
valueBackgroundImageFit → BoxFit?
final
valueBorder → Border?
final
valueBorderRadius → BorderRadiusGeometry?
final
valueBottom → double?
final
valueCancelFocusWhenClick → bool?
final
valueCenterAlign → bool?
final
valueConstraints → BoxConstraints?
final
valueContainerAlignment → AlignmentGeometry?
final
valueDragOutToStatusBar → VoidCallback?
final
valueFlex → int?
final
valueFullHeight → double?
final
valueFullWidth → double?
final
valueGradient → Gradient?
final
valueGradientBorder → Gradient?
final
valueGradientBorderSize → double?
final
valueGravity → MGravity?
final
valueHeight → double?
final
valueHelp → String?
final
valueHeroTag → Object?
final
valueKey → Key?
Main key.
final
valueLeft → double?
Use the Positioned widget.
final
valueMargin → EdgeInsets?
final
valueMaskColor → Color?
final
valueMaterialElevation → double?
final
valueMaterialType → MaterialType?
Material
final
valueObxListener → RxInterface?
Only refresh builder content.
final
valueOnLongPress → VoidCallback?
final
valueOnLongPressMoveUpdate → GestureLongPressMoveUpdateCallback?
final
valueOnLongPressUp → VoidCallback?
final
valueOnScrollStop → VoidCallback?
final
valueOnTap → VoidCallback?
final
valueOpacity → double?
final
valueOutSideAlignment → AlignmentGeometry?
final
valueOutsideBackgroundColor → Color?
final
valueOutsideBorder → Border?
final
valueOutsideBorderRadius → BorderRadiusGeometry?
final
valueOutSizeFlex → bool?
final
valuePadding → EdgeInsets?
Contents:
final
valueRight → double?
final
valueRotate → double?
final
valueSafeArea → SafeArea?
Other
final
valueScale → double?
final
valueScrollable → bool?
Scroll.
final
valueScrollController → ScrollController?
final
valueShadow → BoxShadow?
final
valueShape → BoxShape?
final
valueSigmaX → double?
Blur
final
valueSigmaY → double?
final
valueTabLength → int?
final
valueTop → double?
final
valueTransform → Matrix4?
final
valueVisible → bool?
final
valueWidth → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited