ModifierMaterialApp class

Inheritance
Available extensions

Constructors

ModifierMaterialApp({Key? key, GlobalKey<NavigatorState>? navigatorKey, GlobalKey<ScaffoldMessengerState>? scaffoldMessengerKey, Widget? home, Map<String, Widget Function(BuildContext)> routes = const <String, WidgetBuilder>{}, String? initialRoute, RouteFactory? onGenerateRoute, InitialRouteListFactory? onGenerateInitialRoutes, RouteFactory? onUnknownRoute, bool useInheritedMediaQuery = false, List<NavigatorObserver> navigatorObservers = const <NavigatorObserver>[], TransitionBuilder? builder, TextDirection? textDirection, String title = '', GenerateAppTitle? onGenerateTitle, Color? color, ThemeData? theme, ThemeData? darkTheme, ThemeMode themeMode = ThemeMode.system, Locale? locale, Locale? fallbackLocale, Iterable<LocalizationsDelegate>? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')], bool debugShowMaterialGrid = false, bool showPerformanceOverlay = false, bool checkerboardRasterCacheImages = false, bool checkerboardOffscreenLayers = false, bool showSemanticsDebugger = false, bool debugShowCheckedModeBanner = true, Map<LogicalKeySet, Intent>? shortcuts, ScrollBehavior? scrollBehavior, CustomTransition? customTransition, Map<String, Map<String, String>>? translationsKeys, Translations? translations, VoidCallback? onInit, VoidCallback? onReady, VoidCallback? onDispose, ValueChanged<Routing?>? routingCallback, Transition? defaultTransition, List<GetPage>? getPages, bool? opaqueRoute, bool? enableLog = kDebugMode, LogWriterCallback? logWriterCallback, bool? popGesture, Duration? transitionDuration, bool? defaultGlobalState, SmartManagement smartManagement = SmartManagement.full, Bindings? initialBinding, GetPage? unknownRoute, ThemeData? highContrastTheme, ThemeData? highContrastDarkTheme, Map<Type, Action<Intent>>? actions})
const

Properties

actions → Map<Type, Action<Intent>>?
final
backButtonDispatcher → BackButtonDispatcher?
final
builder → TransitionBuilder?
final
checkerboardOffscreenLayers → bool
final
checkerboardRasterCacheImages → bool
final
color → Color?
final
customTransition → CustomTransition?
final
darkTheme → ThemeData?
final
debugShowCheckedModeBanner → bool
final
debugShowMaterialGrid → bool
final
defaultGlobalState → bool?
final
defaultTransition → Transition?
final
enableLog → bool?
final
fallbackLocale → Locale?
final
getPages → List<GetPage>?
final
hashCode → int
The hash code for this object.
no setterinherited
highContrastDarkTheme → ThemeData?
final
highContrastTheme → ThemeData?
final
home → Widget?
final
initialBinding → Bindings?
final
initialRoute → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
final
localeListResolutionCallback → LocaleListResolutionCallback?
final
localeResolutionCallback → LocaleResolutionCallback?
final
localizationsDelegates → Iterable<LocalizationsDelegate>?
final
logWriterCallback → LogWriterCallback?
final
final
final
onDispose → VoidCallback?
final
onGenerateInitialRoutes → InitialRouteListFactory?
final
onGenerateRoute → RouteFactory?
final
onGenerateTitle → GenerateAppTitle?
final
onInit → VoidCallback?
final
onReady → VoidCallback?
final
onUnknownRoute → RouteFactory?
final
opaqueRoute → bool?
final
popGesture → bool?
final
routeInformationParser → RouteInformationParser<Object>?
final
routeInformationProvider → RouteInformationProvider?
final
routerDelegate → RouterDelegate<Object>?
final
routes → Map<String, WidgetBuilder>?
final
routingCallback → ValueChanged<Routing?>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaffoldMessengerKey → GlobalKey<ScaffoldMessengerState>?
final
scrollBehavior → ScrollBehavior?
final
shortcuts → Map<LogicalKeySet, Intent>?
final
showPerformanceOverlay → bool
final
showSemanticsDebugger → bool
final
smartManagement → SmartManagement
final
supportedLocales → Iterable<Locale>
final
textDirection → TextDirection?
final
theme → ThemeData?
final
themeMode → ThemeMode
final
title → String
final
transitionDuration → Duration?
final
translations → Translations?
final
translationsKeys → Map<String, Map<String, String>>?
final
unknownRoute → GetPage?
final
useInheritedMediaQuery → bool
final

Methods

align(Alignment alignment) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that aligns its widget within itself and optionally sizes itself based on the widget's size.
aspectRatio(double ratio) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that attempts to size the widget to a specific aspect ratio.
assign(List<Widget> list) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that assigns its widget to a given List.
autoHideKeyboard(BuildContext context) → GestureDetector

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

backgroundColor(Color color, {bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that sets its widget's backgruond color
borderRadiusSet(double radius, {bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

bottomSet(double value) → Positioned

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center() → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

centered() → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that aligns its widget within itself and optionally sizes itself based on the widget's size.
click(VoidCallback onTap) → InkWell

Available on Widget, provided by the FlutterComposeUiModifierEvent extension

clipOval({CustomClipper<Rect>? clipper, Clip behavior = Clip.antiAlias}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that clips its widget to an oval shape.
clipPath({CustomClipper<Path>? clipper, Clip behavior = Clip.antiAlias}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that clips its widget to a path.
clipRect({CustomClipper<Rect>? clipper, Clip behavior = Clip.hardEdge}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that clips its widget to a rectangular shape.
corner(double radius, {bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that clips its widget's corners to the specified radius.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded([int? flex]) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

flex([int? flex]) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that wraps its widget in an Expanded view.
frame({double? width, double? height, bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that sets its widget's frame size.
heightSet(double value) → Container

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

help(String? text, {bool? below}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that sets its widget's frame size.
leftSet(double value) → Positioned

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

margin({double? all, double? top, double? bottom, double? leading, double? trailing, double? horizontal, double? vertical, bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that insets margin around its widget by the given value(s).
marginRight(double right) → Widget

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

material() → Material

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset({double x = 0, double y = 0, bool transformHitTests = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that translates its widget to the specified offset.
onHover(void event(bool), {bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that makes its widget (partially) transparent.
onTap(void event(), {bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that makes its widget (partially) transparent.
opacity(double opacity) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that makes its widget (partially) transparent.
padding({double? all, double? top, double? bottom, double? leading, double? trailing, double? horizontal, double? vertical, bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that insets its widget by the given padding.
positioned({double? left, double? top, double? right, double? bottom}) → Positioned

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

rightSet(double value) → Positioned

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

rotate(double angle) → Transform

Available on Widget, provided by the FlutterUIModifiersWidget extension

Creates a modifier that transforms its widget using a rotation around the center.
safeArea({bool left = true, bool top = true, bool right = true, bool bottom = true, EdgeInsets minimum = EdgeInsets.zero, bool maintainBottomViewPadding = false}) → SafeArea

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

scale(double scale, {Offset? origin, AlignmentGeometry? alignment, bool transformHitTests = true}) → Transform

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that scales its widget uniformly.
setHeight(double value) → Container

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

setWidth(double value) → Container

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

shadow(double radius, {Color color = const Color.fromRGBO(0, 0, 0, .5), double blur = 25, double x = 0, double y = 0, bool handover = true}) → Widget

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that sets its widget's frame size.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
topSet(double value) → Positioned

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
transform(Matrix4 transform, {Offset? origin, AlignmentGeometry? alignment, bool transformHitTests = true}) → Transform

Available on Widget, provided by the FlutterUIModifiersWidget extension

A modifier that transforms its widget.
widthSet(double value) → Container

Available on Widget, provided by the FlutterUIModifiersWidgetLayout extension

Operators

operator *(int times) → List<Widget>

Available on Widget, provided by the WidgetMultiple extension

operator ==(Object other) → bool
The equality operator.
inherited