MHeaderDelegate class

Please use SliverPinnedToBoxAdapter in extended_sliver plugin.

Inheritance

Constructors

MHeaderDelegate({required double minHeight, required double maxHeight, required Widget child})

Properties

child → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
maxExtent → double
The size of the header when it is not shrinking at the top of the viewport.
no setteroverride
maxHeight → double
final
minExtent → double
The smallest size to allow the header to reach, when it shrinks at the start of the viewport.
no setteroverride
minHeight → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showOnScreenConfiguration → PersistentHeaderShowOnScreenConfiguration?
Specifies how floating headers and pinned headers should behave in response to RenderObject.showOnScreen calls.
no setterinherited
snapConfiguration → FloatingHeaderSnapConfiguration?
Specifies how floating headers should animate in and out of view.
no setterinherited
stretchConfiguration → OverScrollHeaderStretchConfiguration?
Specifies an AsyncCallback and offset for execution.
no setterinherited
vsync → TickerProvider?
A TickerProvider to use when animating the header's size changes.
no setterinherited

Methods

build(BuildContext context, double shrinkOffset, bool overlapsContent) → Widget
The widget to place inside the SliverPersistentHeader.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant SliverPersistentHeaderDelegate oldDelegate) → bool
Whether this delegate is meaningfully different from the old delegate.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited