MLanUtil class

Constructors

MLanUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

arabicLan → bool
no setter
currentLocale → Locale
no setter
defLanDisplayName ↔ String
getter/setter pair

Static Methods

setNewLan(String languageCode) → Future<void>

Constants

languageSaveKey → const String