MPickerImageUtil class

Constructors

MPickerImageUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

changeAvatar() → Future<String?>
Warning: Please do not use Completer.
pickImage(ImageSource imageSource) → Future<String?>
requestPermissionsCamera() → Future<PermissionStatus?>
The video call will be used it on started on April 17, 2024.
requestPermissionsMicrophone() → Future<PermissionStatus?>
Actually, just that Implement for video call.
saveImage(String imagePath) → Future<String?>
Question: why the application ID in the local path is different every time I launch the app use flutter in ios?